@@ -40,7 +40,7 @@ def get_select2_css_libs():
     if settings.configured and settings.DEBUG:
         return ('css/select2.css', 'css/extra.css', )
     else:
-        return ('css/all.min.js', )
+        return ('css/all.min.css', )
 
 ### Light mixin and widgets ###
 
@@ -346,10 +346,12 @@ class HeavySelect2Mixin(Select2Mixin):
 
                 3. Otherwise, check the cached results. When the user searches in the fields then all the returned
                 responses from server, which has the value and label mapping, are cached by ``heavy_data.js``.
+                
+        :type userGetValTextFuncName: :py:obj:`str`
 
-                .. note:: Since version 3.2.0, cookies or localStorage are no longer checked or used. All
-                    :py:class:`~.field.HeavyChoiceField` must override :py:meth:`~.fields.HeavyChoiceField.get_val_txt`.
-                    If you are only using heavy widgets in your own fields then you should override :py:meth:`.render_texts`.
+        .. tip:: Since version 3.2.0, cookies or localStorage are no longer checked or used. All
+            :py:class:`~.field.HeavyChoiceField` must override :py:meth:`~.fields.HeavyChoiceField.get_val_txt`.
+            If you are only using heavy widgets in your own fields then you should override :py:meth:`.render_texts`.
         """
         self.field = None
         self.options = dict(self.options)  # Making an instance specific copy
